.. image:: https://github.com/zhengp0/xspline/workflows/python-build/badge.svg
    :target: https://github.com/zhengp0/xspline/actions

.. image:: https://badge.fury.io/py/xspline.svg
    :target: https://badge.fury.io/py/xspline

XSpline
=======

Advanced spline package that provides b-spline bases, their derivatives and integrals.
